@@ -40,26 +40,26 @@ class MainWindow(QMainWindow, Ui_MainWindow):
 
  
         # create a new Sound object from a file
-        self.sound1=mixer.Sound("stylo_smpl/a2.wav")      #a
-        self.sound15=mixer.Sound("stylo_smpl/a#2.wav") #a sharp
-        self.sound2=mixer.Sound("stylo_smpl/b2.wav")      #b
-        self.sound3=mixer.Sound("stylo_smpl/c3.wav")      #c
-        self.sound35=mixer.Sound("stylo_smpl/c#3.wav")      #c sharp
-        self.sound4=mixer.Sound("stylo_smpl/d3.wav")      #d
-        self.sound45=mixer.Sound("stylo_smpl/d#3.wav")  #d sharp
-        self.sound5=mixer.Sound("stylo_smpl/e3.wav")       #e
-        self.sound6=mixer.Sound("stylo_smpl/f3.wav")       #f
-        self.sound65=mixer.Sound("stylo_smpl/f#3.wav")  #f sharp
-        self.sound7=mixer.Sound("stylo_smpl/g3.wav")       #g
-        self.sound75=mixer.Sound("stylo_smpl/g#3.wav")  #g sharp
-        self.sound8=mixer.Sound("stylo_smpl/a3.wav")      #a
-        self.sound85=mixer.Sound("stylo_smpl/a#3.wav")  #a sharp
-        self.sound9=mixer.Sound("stylo_smpl/b3.wav")      #b
-        self.sound10=mixer.Sound("stylo_smpl/c4.wav")    #c
-        self.sound105=mixer.Sound("stylo_smpl/c#4.wav") #c sharp
-        self.sound11=mixer.Sound("stylo_smpl/d4.wav")     #d
-        self.sound115=mixer.Sound("stylo_smpl/d#4.wav")  #d sharp
-        self.sound12=mixer.Sound("stylo_smpl/e4.wav")     #e
+        self.sound1=mixer.Sound("/home/opt/maelophone/stylo_smpl/a2.wav")      #a
+        self.sound15=mixer.Sound("/home/opt/maelophone/stylo_smpl/a#2.wav") #a sharp
+        self.sound2=mixer.Sound("/home/opt/maelophone/stylo_smpl/b2.wav")      #b
+        self.sound3=mixer.Sound("/home/opt/maelophone/stylo_smpl/c3.wav")      #c
+        self.sound35=mixer.Sound("/home/opt/maelophon/estylo_smpl/c#3.wav")      #c sharp
+        self.sound4=mixer.Sound("/home/opt/maelophone/stylo_smpl/d3.wav")      #d
+        self.sound45=mixer.Sound("/home/opt/maelophone/stylo_smpl/d#3.wav")  #d sharp
+        self.sound5=mixer.Sound("/home/opt/maelophone/stylo_smpl/e3.wav")       #e
+        self.sound6=mixer.Sound("/home/opt/maelophone/stylo_smpl/f3.wav")       #f
+        self.sound65=mixer.Sound("/home/opt/maelophone/stylo_smpl/f#3.wav")  #f sharp
+        self.sound7=mixer.Sound("/home/opt/maelophone/stylo_smpl/g3.wav")       #g
+        self.sound75=mixer.Sound("/home/opt/maelophone/stylo_smpl/g#3.wav")  #g sharp
+        self.sound8=mixer.Sound("/home/opt/maelophone/stylo_smpl/a3.wav")      #a
+        self.sound85=mixer.Sound("/home/opt/maelophone/stylo_smpl/a#3.wav")  #a sharp
+        self.sound9=mixer.Sound("/home/opt/maelophone/stylo_smpl/b3.wav")      #b
+        self.sound10=mixer.Sound("/home/opt/maelophone/stylo_smpl/c4.wav")    #c
+        self.sound105=mixer.Sound("/home/opt/maelophone/stylo_smpl/c#4.wav") #c sharp
+        self.sound11=mixer.Sound("/home/opt/maelophone/stylo_smpl/d4.wav")     #d
+        self.sound115=mixer.Sound("/home/opt/maelophone/stylo_smpl/d#4.wav")  #d sharp
+        self.sound12=mixer.Sound("/home/opt/maelophone/stylo_smpl/e4.wav")     #e
      
         self.decay=0
         self.vol=0.5
@@ -78,7 +78,7 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         #self.fullScreen=0
         
         #Load the Keyboard picture. The Graphics View is 640X110px, each button os 53px wide with  at the ends2pix border
-        self.svgKeys=QGraphicsSvgItem("keys.svg")
+        self.svgKeys=QGraphicsSvgItem("/home/opt/maelophone/keys.svg")
         renderer=self.svgKeys.renderer()
         self.svgKeys.setZValue(1)
         self.svgKeys.setPos(0, 0)
